Zowe Python Client SDK
======================
  
The Zowe Python Client SDK consists of Python packages that enable programmatic interactions with z/OS REST API interfaces.

[Zowe Docs](https://docs.zowe.org/stable/user-guide/sdks-using) provide more information on installing and using the SDK.


SDK Usage
-----------------

For more information and syntax examples, refer to the readme file in each package:

- [Core](core/README.md): Shared functionality across all other Python SDK packages.
- [z/OS Console](zos_console/README.md): Perform z/OS console operations.
- [z/OS Files](zos_files/README.md): Work with data sets on z/OS.
- [z/OS Jobs](zos_jobs/README.md): Work with batch jobs on z/OS.
- [z/OS TSO](zos_tso/README.md): Interact with TSO/E adress spaces on z/OS.
- [z/OSMF](zosmf/README.md): Query z/OSMF data (e.g.: connection status, list of available systems).
